@@ -268,7 +268,15 @@ typedef struct __gf_dvb_tuner GF_Tuner;
 #define GF_M2TS_MAX_SERVICES	65535
 
 /*Maximum size of the buffer in UDP */
-#define UDP_BUFFER_SIZE	0x4000
+#ifdef WIN32
+#define GF_M2TS_UDP_BUFFER_SIZE	0x80000
+#else
+//fixme - issues on linux and OSX with large stack size
+//we need to change default stack size for TS thread
+#define GF_M2TS_UDP_BUFFER_SIZE	0x40000
+#endif
+
+#define GF_M2TS_MAX_PCR	2576980377811ULL
 
 /*returns readable name for given stream type*/
 const char *gf_m2ts_get_stream_name(u32 streamType);
@@ -509,6 +517,7 @@ typedef struct
 	Bool force_reload;
 	Bool is_paused;
 	Bool is_discontinuity;
+	u64 ntp;
 } GF_M2TS_TemiTimecodeDescriptor;
 
 
@@ -547,6 +556,9 @@ typedef struct
 	Bool is_scalable;
 
 	GF_M2TS_MetadataPointerDescriptor *metadata_pointer_descriptor;
+
+	/*continuity counter check for pure PCR PIDs*/
+	s16 pcr_cc;
 } GF_M2TS_Program;
 
 /*ES flags*/
@@ -566,6 +578,8 @@ enum
 	GF_M2TS_ES_IS_MPE = 1<<5,
 	/*stream is used to send PCR to upper layer*/
 	GF_M2TS_INHERIT_PCR = 1<<6,
+	/*siugnals the stream is used to send the PCR, but is not the original PID carrying it*/
+	GF_M2TS_FAKE_PCR = 1<<7,
 
 	/*all flags above this mask are used by importers & co*/
 	GF_M2TS_ES_STATIC_FLAGS_MASK = 0x0000FFFF,
@@ -711,9 +725,13 @@ typedef struct tag_m2ts_pes
 	GF_M2TS_DVB_Subtitling_Descriptor sub;
 	GF_M2TS_MetadataDescriptor *metadata_descriptor;
 
-
+	//pointer to last received temi
 	char *temi_tc_desc;
 	u32 temi_tc_desc_len, temi_tc_desc_alloc_size;
+
+	//last decoded temi (may be one ahead of time as the last received TEMI)
+	GF_M2TS_TemiTimecodeDescriptor temi_tc;
+	Bool temi_pending;
 } GF_M2TS_PES;
 
 /*SDT information object*/
@@ -913,6 +931,9 @@ struct tag_m2ts_demux
 	/* analyser */
 	FILE *pes_out;
 
+
+	Bool prefix_present;
+
 	Bool direct_mpe;
 
 	Bool dvb_h_demux;
@@ -938,7 +959,7 @@ struct tag_m2ts_demux
 	char* dsmcc_root_dir;
 	GF_List* dsmcc_controler;
 
-	Bool segment_switch;
+	Bool abort_parsing;
 	Bool table_reset;
 
 	//duration estimation
@@ -952,6 +973,7 @@ struct tag_m2ts_demux
 GF_M2TS_Demuxer *gf_m2ts_demux_new();
 void gf_m2ts_demux_del(GF_M2TS_Demuxer *ts);
 void gf_m2ts_reset_parsers(GF_M2TS_Demuxer *ts);
+void gf_m2ts_reset_parsers_for_program(GF_M2TS_Demuxer *ts, GF_M2TS_Program *prog);
 GF_ESD *gf_m2ts_get_esd(GF_M2TS_ES *es);
 GF_Err gf_m2ts_set_pes_framing(GF_M2TS_PES *pes, u32 mode);
 u32 gf_m2ts_pes_get_framing_mode(GF_M2TS_PES *pes);
@@ -966,6 +988,8 @@ GF_M2TS_SDT *gf_m2ts_get_sdt_info(GF_M2TS_Demuxer *ts, u32 program_id);
 
 Bool gf_m2ts_crc32_check(char *data, u32 len);
 
+/*aborts parsing of the current data (typically needed when parsing done by a different thread). If force_reset_pes is set, all pending pes data is discarded*/
+void gf_m2ts_abort_parsing(GF_M2TS_Demuxer *ts, Bool force_reset_pes);
 
 
 typedef struct
@@ -1091,6 +1115,9 @@ typedef struct __m2ts_mux_stream {
 	/*multiplexer time - NOT THE PCR*/
 	GF_M2TS_Time time;
 
+	GF_M2TS_Time next_time;
+	Bool pcr_only_mode;
+
 	/*table tools*/
 	GF_M2TS_Mux_Table *tables;
 	/*total table sizes for bitrate estimation (PMT/PAT/...)*/
@@ -1102,6 +1129,7 @@ typedef struct __m2ts_mux_stream {
 	u32 refresh_rate_ms;
 	Bool table_needs_update;
 	Bool table_needs_send;
+	Bool force_single_au;
 
 	/*minimal amount of bytes we are allowed to copy frome next AU in the current PES. If no more than this
 	is available in PES, don't copy from next*/
@@ -1208,6 +1236,16 @@ enum
 	GF_SEG_BOUNDARY_FORCE_PCR,
 };
 
+/*AU packing per pes configuration*/
+typedef enum
+{
+	/*only audio AUs are packed in a single PES, video and systems are not (recommended default)*/
+	GF_M2TS_PACK_AUDIO_ONLY,
+	/*never pack AUs in a single PES*/
+	GF_M2TS_PACK_NONE,
+	/*always try to pack AUs in a single PES*/
+	GF_M2TS_PACK_ALL
+} GF_M2TS_PackMode;
 
 struct __m2ts_mux {
 	GF_M2TS_Mux_Program *programs;
@@ -1248,7 +1286,9 @@ struct __m2ts_mux {
 
 	Bool force_pat;
 
-	Bool one_au_per_pes;
+	GF_M2TS_PackMode au_pes_mode;
+
+	Bool enable_forced_pcr;
 
 	Bool eos_found;
 	u64 last_br_time_us;
@@ -1292,9 +1332,9 @@ const char *gf_m2ts_mux_process(GF_M2TS_Mux *muxer, u32 *status, u32 *usec_till_
 u32 gf_m2ts_get_sys_clock(GF_M2TS_Mux *muxer);
 u32 gf_m2ts_get_ts_clock(GF_M2TS_Mux *muxer);
 
-/*set muxer in/out single-au pes mode. In this mode, each PES contains one and only one AU*/
-GF_Err gf_m2ts_mux_use_single_au_pes_mode(GF_M2TS_Mux *muxer, Bool strict_au_pes_mode);
+GF_Err gf_m2ts_mux_use_single_au_pes_mode(GF_M2TS_Mux *muxer, GF_M2TS_PackMode au_pes_mode);
 GF_Err gf_m2ts_mux_set_initial_pcr(GF_M2TS_Mux *muxer, u64 init_pcr_value);
+GF_Err gf_m2ts_mux_enable_pcr_only_packets(GF_M2TS_Mux *muxer, Bool enable_forced_pcr);
 
 /*user inteface functions*/
 GF_Err gf_m2ts_program_stream_update_ts_scale(GF_ESInterface *_self, u32 time_scale);
@@ -1333,9 +1373,6 @@ struct __gf_dvb_tuner {
 };
 
 
-// DVB buffer size 188x20
-#define DVB_BUFFER_SIZE 3760
-
 #endif //GPAC_HAS_LINUX_DVB
 
 
